@@ -711,7 +711,7 @@ QVariant AkonadiModel::entityHeaderData(int section, Qt::Orientation orientation
             case ItemListHeaders:
                 if (section < 0  ||  section >= ColumnCount)
                     return QVariant();
-                if (role == Qt::DisplayRole)
+                if (role == Qt::DisplayRole  ||  role == ColumnTitleRole)
                 {
                     switch (section)
                     {
@@ -722,9 +722,9 @@ QVariant AkonadiModel::entityHeaderData(int section, Qt::Orientation orientation
                         case RepeatColumn:
                             return i18nc("@title:column", "Repeat");
                         case ColourColumn:
-                            return QString();
+                            return (role == Qt::DisplayRole) ? QString() : i18nc("@title:column", "Color");
                         case TypeColumn:
-                            return QString();
+                            return (role == Qt::DisplayRole) ? QString() : i18nc("@title:column", "Type");
                         case TextColumn:
                             return i18nc("@title:column", "Message, File or Command");
                         case TemplateNameColumn:
@@ -1073,6 +1073,7 @@ QPixmap* AkonadiModel::eventIcon(const KAEvent& event) const
             if (event.actionSubType() == KAEvent::FILE)
                 return mFileIcon;
             // fall through to ACT_DISPLAY_COMMAND
+            Q_FALLTHROUGH();
         case KAEvent::ACT_DISPLAY_COMMAND:
         default:
             return mTextIcon;
@@ -1183,7 +1184,7 @@ void AkonadiModel::reload()
 {
     qCDebug(KALARM_LOG) << "AkonadiModel::reload";
     const Collection::List collections = mMonitor->collectionsMonitored();
-    foreach (const Collection& collection, collections)
+    for (const Collection& collection : collections)
     {
         mMonitor->setCollectionMonitored(collection, false);
         mMonitor->setCollectionMonitored(collection, true);
@@ -1238,7 +1239,7 @@ Item::Id AkonadiModel::findItemId(const KAEvent& event)
     Qt::MatchFlags flags = (colId < 0) ? Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchCaseSensitive | Qt::MatchWrap
                                        : Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchCaseSensitive;
     const QModelIndexList indexes = match(start, RemoteIdRole, event.id(), -1, flags);
-    foreach (const QModelIndex& ix, indexes)
+    for (const QModelIndex& ix : indexes)
     {
         if (ix.isValid())
         {
@@ -1389,7 +1390,7 @@ bool AkonadiModel::addEvent(KAEvent& event, Collection& collection)
     Item item;
     if (!event.setItemPayload(item, collection.contentMimeTypes()))
     {
-        qCWarning(KALARM_LOG) << "Invalid mime type for collection";
+        qCWarning(KALARM_LOG) << "AkonadiModel::addEvent: Invalid mime type for collection";
         return false;
     }
     event.setItemId(item.id());
@@ -1426,7 +1427,7 @@ qCDebug(KALARM_LOG)<<"item id="<<itemId;
 qCDebug(KALARM_LOG)<<"item id="<<item.id()<<", revision="<<item.revision();
     if (!newEvent.setItemPayload(item, collection.contentMimeTypes()))
     {
-        qCWarning(KALARM_LOG) << "Invalid mime type for collection";
+        qCWarning(KALARM_LOG) << "AkonadiModel::updateEvent: Invalid mime type for collection";
         return false;
     }
 //    setData(ix, QVariant::fromValue(item), ItemRole);
@@ -1670,7 +1671,7 @@ void AkonadiModel::slotRowsAboutToBeRemoved(const QModelIndex& parent, int start
     const EventList events = eventList(parent, start, end);
     if (!events.isEmpty())
     {
-        foreach (const Event& event, events)
+        for (const Event& event : events)
             qCDebug(KALARM_LOG) << "Collection:" << event.collection.id() << ", Event ID:" << event.event.id();
         Q_EMIT eventsToBeRemoved(events);
     }
@@ -1824,7 +1825,7 @@ void AkonadiModel::slotMonitoredItemChanged(const Akonadi::Item& item, const QSe
     if (!evnt.isValid())
         return;
     const QModelIndexList indexes = modelIndexesForItem(this, item);
-    foreach (const QModelIndex& index, indexes)
+    for (const QModelIndex& index : indexes)
     {
         if (index.isValid())
         {
