@@ -29,8 +29,8 @@
 #include "messagebox.h"
 #include "preferences.h"
 
-#include <KCalCore/MemoryCalendar>
-#include <KCalCore/ICalFormat>
+#include <KCalendarCore/MemoryCalendar>
+#include <KCalendarCore/ICalFormat>
 
 #include <KLocalizedString>
 #include <KIO/StatJob>
@@ -45,10 +45,10 @@
 #include "kalarm_debug.h"
 
 using namespace Akonadi;
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace KAlarmCal;
 
-static KACalendar::Compat fix(const KCalCore::FileStorage::Ptr&);
+static KACalendar::Compat fix(const KCalendarCore::FileStorage::Ptr&);
 
 static const QString displayCalendarName = QStringLiteral("displaying.ics");
 static const Collection::Id DISPLAY_COL_ID = -1;   // collection ID used for displaying calendar
@@ -564,11 +564,13 @@ void AlarmCalendar::slotEventChanged(const AkonadiModel::Event& event)
     if (!updated)
         addNewEvent(event.collection, new KAEvent(event.event));
 
-    bool enabled = event.event.enabled();
-    checkForDisabledAlarms(!enabled, enabled);
-    if (added  &&  enabled  &&  event.event.category() == CalEvent::ACTIVE
-    &&  event.event.repeatAtLogin())
-        Q_EMIT atLoginEventAdded(event.event);
+    if (event.event.category() == CalEvent::ACTIVE)
+    {
+        bool enabled = event.event.enabled();
+        checkForDisabledAlarms(!enabled, enabled);
+        if (added  &&  enabled  &&  event.event.repeatAtLogin())
+            Q_EMIT atLoginEventAdded(event.event);
+    }
 }
 
 /******************************************************************************
