@@ -51,10 +51,10 @@
 #include <AkonadiCore/itemfetchjob.h>
 #include <AkonadiCore/itemfetchscope.h>
 #include <AkonadiWidgets/controlgui.h>
-#include <KCalCore/MemoryCalendar>
+#include <KCalendarCore/MemoryCalendar>
 #include <KCalUtils/kcalutils/icaldrag.h>
 using namespace Akonadi;
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace KCalUtils;
 #include <KAboutData>
 #include <ktoolbar.h>
